package com.sun.org.apache.xml.internal.security;

import com.sun.org.slf4j.internal.LoggerFactory;
import org.w3c.dom.Attr;
import org.w3c.dom.Node;
import java.util.ArrayList;
import org.w3c.dom.Element;
import com.sun.org.apache.xml.internal.security.utils.XMLUtils;
import java.security.PrivilegedActionException;
import com.sun.org.apache.xml.internal.security.exceptions.XMLSecurityException;
import com.sun.org.apache.xml.internal.security.keys.keyresolver.KeyResolver;
import com.sun.org.apache.xml.internal.security.utils.resolver.ResourceResolver;
import com.sun.org.apache.xml.internal.security.c14n.Canonicalizer;
import com.sun.org.apache.xml.internal.security.algorithms.JCEMapper;
import com.sun.org.apache.xml.internal.security.algorithms.SignatureAlgorithm;
import com.sun.org.apache.xml.internal.security.transforms.Transform;
import com.sun.org.apache.xml.internal.security.utils.ElementProxy;
import java.security.PrivilegedExceptionAction;
import com.sun.org.apache.xml.internal.security.utils.I18n;
import java.security.AccessController;
import java.io.InputStream;
import com.sun.org.slf4j.internal.Logger;

public class Init
{
    public static final String CONF_NS = "http://www.xmlsecurity.org/NS/#configuration";
    private static final Logger LOG;
    private static boolean alreadyInitialized;
    
    public Init() {
    }
    
    public static final synchronized boolean isInitialized() {
        return Init.alreadyInitialized;
    }
    
    public static synchronized void init() {
        if (Init.alreadyInitialized) {
            return;
        }
        InputStream inputStream = (InputStream)AccessController.doPrivileged(()/*  */ -> {
            String name = System.getProperty("com.sun.org.apache.xml.internal.security.resource.config");
            if (name == null) {
                return null;
            }
            return Init.class.getResourceAsStream(name);
        });
        if (inputStream == null) {
            dynamicInit();
        }
        else {
            fileInit(inputStream);
        }
        Init.alreadyInitialized = true;
        return;
    }
    
    private static void dynamicInit() {
        I18n.init("en", "US");
        Init.LOG.debug("Registering default algorithms");
        try {
            AccessController.doPrivileged(new PrivilegedExceptionAction<Void>() {
                @Override
                public Void run() throws XMLSecurityException {
                    ElementProxy.registerDefaultPrefixes();
                    Transform.registerDefaultAlgorithms();
                    SignatureAlgorithm.registerDefaultAlgorithms();
                    JCEMapper.registerDefaultAlgorithms();
                    Canonicalizer.registerDefaultAlgorithms();
                    ResourceResolver.registerDefaultResolvers();
                    KeyResolver.registerDefaultResolvers();
                    return null;
                }
            });
        }
        catch (PrivilegedActionException ex) {
            XMLSecurityException e = (XMLSecurityException)ex.getException();
            Init.LOG.error(e.getMessage(), e);
            e.printStackTrace();
        }
    }
    
    private static void fileInit(InputStream is) {
        try {
            Node node;
            for (node = XMLUtils.createDocumentBuilder(false).parse(is).getFirstChild(); node != null && !"Configuration".equals(node.getLocalName()); node = node.getNextSibling()) {}
            if (node == null) {
                Init.LOG.error("Error in reading configuration file - Configuration element not found");
                return;
            }
            for (Node node2 = node.getFirstChild(); node2 != null; node2 = node2.getNextSibling()) {
                if (1 == node2.getNodeType()) {
                    String localName = node2.getLocalName();
                    if ("ResourceBundles".equals(localName)) {
                        Element element = (Element)node2;
                        Attr attributeNodeNS = element.getAttributeNodeNS(null, "defaultLanguageCode");
                        Attr attributeNodeNS2 = element.getAttributeNodeNS(null, "defaultCountryCode");
                        I18n.init((attributeNodeNS == null) ? null : attributeNodeNS.getNodeValue(), (attributeNodeNS2 == null) ? null : attributeNodeNS2.getNodeValue());
                    }
                    if ("CanonicalizationMethods".equals(localName)) {
                        Element[] selectNodes;
                        for (Element element2 : selectNodes = XMLUtils.selectNodes(node2.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "CanonicalizationMethod")) {
                            String attributeNS = element2.getAttributeNS(null, "URI");
                            String attributeNS2 = element2.getAttributeNS(null, "JAVACLASS");
                            try {
                                Canonicalizer.register(attributeNS, attributeNS2);
                                Init.LOG.debug("Canonicalizer.register({}, {})", new Object[] { attributeNS, attributeNS2 });
                            }
                            catch (ClassNotFoundException ex) {
                                Init.LOG.error(I18n.translate("algorithm.classDoesNotExist", new Object[] { attributeNS, attributeNS2 }));
                            }
                        }
                    }
                    if ("TransformAlgorithms".equals(localName)) {
                        Element[] selectNodes2;
                        for (Element element3 : selectNodes2 = XMLUtils.selectNodes(node2.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "TransformAlgorithm")) {
                            String attributeNS3 = element3.getAttributeNS(null, "URI");
                            String attributeNS4 = element3.getAttributeNS(null, "JAVACLASS");
                            try {
                                Transform.register(attributeNS3, attributeNS4);
                                Init.LOG.debug("Transform.register({}, {})", new Object[] { attributeNS3, attributeNS4 });
                            }
                            catch (ClassNotFoundException ex2) {
                                Init.LOG.error(I18n.translate("algorithm.classDoesNotExist", new Object[] { attributeNS3, attributeNS4 }));
                            }
                            catch (NoClassDefFoundError noClassDefFoundError) {
                                Init.LOG.warn("Not able to found dependencies for algorithm, I'll keep working.");
                            }
                        }
                    }
                    if ("JCEAlgorithmMappings".equals(localName)) {
                        Node item = ((Element)node2).getElementsByTagName("Algorithms").item(0);
                        if (item != null) {
                            Element[] selectNodes3;
                            for (Element el : selectNodes3 = XMLUtils.selectNodes(item.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "Algorithm")) {
                                JCEMapper.register(el.getAttributeNS(null, "URI"), new JCEMapper.Algorithm(el));
                            }
                        }
                    }
                    if ("SignatureAlgorithms".equals(localName)) {
                        Element[] selectNodes4;
                        for (Element element4 : selectNodes4 = XMLUtils.selectNodes(node2.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "SignatureAlgorithm")) {
                            String attributeNS5 = element4.getAttributeNS(null, "URI");
                            String attributeNS6 = element4.getAttributeNS(null, "JAVACLASS");
                            try {
                                SignatureAlgorithm.register(attributeNS5, attributeNS6);
                                Init.LOG.debug("SignatureAlgorithm.register({}, {})", new Object[] { attributeNS5, attributeNS6 });
                            }
                            catch (ClassNotFoundException ex3) {
                                Init.LOG.error(I18n.translate("algorithm.classDoesNotExist", new Object[] { attributeNS5, attributeNS6 }));
                            }
                        }
                    }
                    if ("ResourceResolvers".equals(localName)) {
                        Element[] selectNodes5;
                        for (Element element5 : selectNodes5 = XMLUtils.selectNodes(node2.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "Resolver")) {
                            String attributeNS7 = element5.getAttributeNS(null, "JAVACLASS");
                            String attributeNS8 = element5.getAttributeNS(null, "DESCRIPTION");
                            if (attributeNS8 != null && attributeNS8.length() > 0) {
                                Init.LOG.debug("Register Resolver: {}: {}", new Object[] { attributeNS7, attributeNS8 });
                            }
                            else {
                                Init.LOG.debug("Register Resolver: {}: For unknown purposes", new Object[] { attributeNS7 });
                            }
                            try {
                                ResourceResolver.register(attributeNS7);
                            }
                            catch (Throwable e) {
                                Init.LOG.warn("Cannot register:" + attributeNS7 + " perhaps some needed jars are not installed", e);
                            }
                        }
                    }
                    if ("KeyResolver".equals(localName)) {
                        Element[] selectNodes6 = XMLUtils.selectNodes(node2.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "Resolver");
                        ArrayList classNames = new ArrayList(selectNodes6.length);
                        for (Element element6 : selectNodes6) {
                            String attributeNS9 = element6.getAttributeNS(null, "JAVACLASS");
                            String attributeNS10 = element6.getAttributeNS(null, "DESCRIPTION");
                            if (attributeNS10 != null && attributeNS10.length() > 0) {
                                Init.LOG.debug("Register Resolver: {}: {}", new Object[] { attributeNS9, attributeNS10 });
                            }
                            else {
                                Init.LOG.debug("Register Resolver: {}: For unknown purposes", new Object[] { attributeNS9 });
                            }
                            classNames.add(attributeNS9);
                        }
                        KeyResolver.registerClassNames(classNames);
                    }
                    if ("PrefixMappings".equals(localName)) {
                        Init.LOG.debug("Now I try to bind prefixes:");
                        Element[] selectNodes7;
                        for (Element element7 : selectNodes7 = XMLUtils.selectNodes(node2.getFirstChild(), "http://www.xmlsecurity.org/NS/#configuration", "PrefixMapping")) {
                            String attributeNS11 = element7.getAttributeNS(null, "namespace");
                            String attributeNS12 = element7.getAttributeNS(null, "prefix");
                            Init.LOG.debug("Now I try to bind {} to {}", new Object[] { attributeNS12, attributeNS11 });
                            ElementProxy.setDefaultPrefix(attributeNS11, attributeNS12);
                        }
                    }
                }
            }
        }
        catch (Exception e2) {
            Init.LOG.error("Bad: ", e2);
        }
    }
    
    static {
        LOG = LoggerFactory.getLogger(Init.class);
        Init.alreadyInitialized = false;
    }
}
